@@ -1,3 +1,14 @@
+/*
+ * coap_config.h.lwip -- LwIP configuration for libcoap
+ *
+ * Copyright (C) 2021 Olaf Bergmann <bergmann@tzi.org> and others
+ *
+ * SPDX-License-Identifier: BSD-2-Clause
+ *
+ * This file is part of the CoAP library libcoap. Please see README for terms
+ * of use.
+ */
+
 #ifndef COAP_CONFIG_H_
 #define COAP_CONFIG_H_
 
@@ -11,9 +22,13 @@
 #define COAP_CONSTRAINED_STACK 1
 #endif
 
-#define PACKAGE_NAME "libcoap-lwip"
-#define PACKAGE_VERSION "?"
-#define PACKAGE_STRING PACKAGE_NAME PACKAGE_VERSION
+#ifndef COAP_DISABLE_TCP
+#define COAP_DISABLE_TCP 1
+#endif
+
+#define PACKAGE_NAME "libcoap"
+#define PACKAGE_VERSION "4.3.0"
+#define PACKAGE_STRING "libcoap 4.3.0"
 
 #define assert(x) LWIP_ASSERT("CoAP assert failed", x)
 
